@@ -5,25 +5,17 @@
 //! ```
 //! cargo test -- --include-ignored
 //! ````
-
-use predicates::prelude::*;
-
-use crate::helpers::project::binary;
-use crate::helpers::project_builder::tmp_dir;
-
-use assert_cmd::prelude::*;
+use crate::helpers::prelude::*;
 
 #[test]
 #[ignore]
 fn git_flag_can_be_skipped_and_cargo_will_use_correct_implementation() {
     // with --git
-    let dir = tmp_dir().build();
+    let dir = tempdir().build();
     binary()
-        .arg("generate")
-        .arg("--name")
-        .arg("my-proj")
-        .arg("--init")
-        .arg("git://github.com/ashleygwilliams/wasm-pack-template")
+        .arg_name("my-proj")
+        .flag_init()
+        .arg("git://github.com/rustwasm/wasm-pack-template")
         .current_dir(dir.path())
         .assert()
         .success()
@@ -34,24 +26,21 @@ fn git_flag_can_be_skipped_and_cargo_will_use_correct_implementation() {
 #[ignore]
 fn plain_git_repo_works() {
     let possible_urls = vec![
-        "git://github.com/ashleygwilliams/wasm-pack-template",
-        "git://github.com/ashleygwilliams/wasm-pack-template.git",
-        "https://github.com/ashleygwilliams/wasm-pack-template.git",
-        "https://github.com/ashleygwilliams/wasm-pack-template",
-        "http://github.com/ashleygwilliams/wasm-pack-template.git",
-        "http://github.com/ashleygwilliams/wasm-pack-template",
+        "git://github.com/rustwasm/wasm-pack-template",
+        "git://github.com/rustwasm/wasm-pack-template.git",
+        "https://github.com/rustwasm/wasm-pack-template.git",
+        "https://github.com/rustwasm/wasm-pack-template",
+        "http://github.com/rustwasm/wasm-pack-template.git",
+        "http://github.com/rustwasm/wasm-pack-template",
     ];
 
     // with --git
     for remote in possible_urls {
-        let dir = tmp_dir().build();
+        let dir = tempdir().build();
         binary()
-            .arg("generate")
-            .arg("--git")
-            .arg(remote)
-            .arg("--name")
-            .arg("my-proj")
-            .arg("--init")
+            .arg_git(remote)
+            .arg_name("my-proj")
+            .flag_init()
             .current_dir(dir.path())
             .assert()
             .success()
@@ -62,18 +51,17 @@ fn plain_git_repo_works() {
 #[test]
 #[ignore]
 fn abbreviation_for_github_works() {
-    let dir = tmp_dir().build();
+    let dir = tempdir().build();
     binary()
-        .arg("generate")
-        .arg("--name")
-        .arg("my-proj")
-        .arg("ashleygwilliams/wasm-pack-template")
+
+        .arg_name("my-proj")
+        .arg("rustwasm/wasm-pack-template")
         .current_dir(dir.path())
         .assert()
         .success()
         .stdout(predicates::str::contains("Done!").and(
             predicates::str::contains(
-                "Favorite `ashleygwilliams/wasm-pack-template` not found in config, using it as a git repository: https://github.com/ashleygwilliams/wasm-pack-template.git"
+                "Favorite `rustwasm/wasm-pack-template` not found in config, using it as a git repository: https://github.com/rustwasm/wasm-pack-template.git"
             )).from_utf8());
 }
 
@@ -86,14 +74,11 @@ mod ssh_remote {
     #[ignore]
     // for now only locally working
     fn it_should_support_a_public_repo() {
-        let dir = tmp_dir().build();
+        let dir = tempdir().build();
 
         binary()
-            .arg("generate")
-            .arg("--git")
-            .arg("git@github.com:ashleygwilliams/wasm-pack-template.git")
-            .arg("--name")
-            .arg("foobar-project")
+            .arg_git("git@github.com:rustwasm/wasm-pack-template.git")
+            .arg_name("foobar-project")
             .current_dir(dir.path())
             .assert()
             .success()
@@ -107,14 +92,11 @@ mod ssh_remote {
     #[ignore]
     // for now only locally working
     fn it_should_support_a_private_repo() {
-        let dir = tmp_dir().build();
+        let dir = tempdir().build();
 
         binary()
-            .arg("generate")
-            .arg("--git")
-            .arg("git@github.com:cargo-generate/wasm-pack-template.git")
-            .arg("--name")
-            .arg("foobar-project")
+            .arg_git("git@github.com:cargo-generate/wasm-pack-template.git")
+            .arg_name("foobar-project")
             .current_dir(dir.path())
             .assert()
             .success()
@@ -128,16 +110,13 @@ mod ssh_remote {
     #[ignore]
     // for now only locally working
     fn it_should_support_a_custom_ssh_key() {
-        let dir = tmp_dir().build();
+        let dir = tempdir().build();
 
         binary()
-            .arg("generate")
             .arg("-i")
             .arg("~/workspaces/rust/cargo-generate-org/.env/id_rsa_ci")
-            .arg("--git")
-            .arg("git@github.com:cargo-generate/wasm-pack-template.git")
-            .arg("--name")
-            .arg("foobar-project")
+            .arg_git("git@github.com:cargo-generate/wasm-pack-template.git")
+            .arg_name("foobar-project")
             .current_dir(dir.path())
             .assert()
             .success()
